@@ -15,11 +15,11 @@ use Carp 'croak';
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =cut
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 =head1 SYNOPSIS
 
@@ -69,13 +69,17 @@ For example,
 produces the following output:
 
     not ok 1
-    # Failed test at ... line 30.
+    # Failed test at ... line 13.
+    #     Original: 1000, 1100
     #     DOP: 2
     #     Delta: 100
     #     Multiplier: 0.01 (1e-2)
     #     Diff: round(1)
     #     Comparison: 1 == 0
 
+B<Original>: the untouched values of C<$actual> and C<$expected> as
+passed in to the test.
+
 B<DOP>: the I<digits of precision> used.
 
 B<Delta>: the absolute difference between C<$actual> and C<$expected>.
@@ -177,12 +181,14 @@ sub _compare {
     my $to_round = $delta * $mult;
     my $diff     = int $to_round + 0.5;
 
-    my $diag = '';
-    $diag .= "    DOP: $_DOP\n";
-    $diag .= "    Delta: $delta\n";
-    $diag .= "    Multiplier: $mult (1e" . ($_DOP-$scale) . ")\n";
-    $diag .= "    Diff: round($to_round)\n";
-    $diag .= "    Comparison: $diff " . ($eq_noteq eq K_EQUAL ? '==' : '!=') . " 0\n";
+    my $diag = join '', map { "    $_\n" } (
+        "Original values: $actual, $expected",
+        "DOP: $_DOP",
+        "Delta: $delta",
+        "Multiplier: $mult (1e" . ($_DOP-$scale) . ")",
+        "Diff: round($to_round)",
+        "Comparison: $diff " . ($eq_noteq eq K_EQUAL ? '==' : '!=') . " 0",
+    );
 
     my $ctx = context( level => 1 );
     my $ok = $eq_noteq eq K_EQUAL ? $diff == 0 : $diff != 0;
